---
name: Bug report
about: Report a bug you've found in this extension
title: ''
labels: bug
assignees: ''

---

**Description**
A clear and concise description of what the bug is.

**Expected Behaviour**
What you expected to happen instead.

**To Reproduce**
Steps to reproduce the bug.

**Error Log**
Paste any relevant error logs below:
```
<error log here>
```

**Screenshots**
Add screenshots to illustrate the bug if you want.

**Your Setup**
 - CKAN version: [e.g. 2.8.3]
 - Commit/version of this repo:
 - Browser (if relevant): [e.g. chrome, safari]

**Anything Else?**
...
